@@ -37,7 +37,14 @@ private Q_SLOTS:
 
         // ignoring embedded thumbnail as it is too small
         QTest::addRow("jpg_embedded_thumbnail2") << "castle.jpg"
-                                                << "castle_thumb_256.png" << 2.0;
+                                                 << "castle_thumb_256.png" << 2.0;
+
+        // image using 4 colors table
+        QTest::addRow("Screen_color_test_Amiga_4colors") << "Screen_color_test_Amiga_4colors.png"
+                                                         << "Screen_color_test_Amiga_4colors_converted.png" << 2.0;
+
+        QTest::addRow("folder-database.svg") << "folder-database.svg"
+                                             << "folder-database-128@2.png" << 2.0;
     }
 
     void testThumbnail()
@@ -47,7 +54,7 @@ private Q_SLOTS:
         QFETCH(qreal, dpr);
 
         QStandardPaths::setTestModeEnabled(true);
-        qputenv("KIOSLAVE_ENABLE_TESTMODE", "1"); // ensure the worker call QStandardPaths::setTestModeEnabled too
+        qputenv("KIOWORKER_ENABLE_TESTMODE", "1"); // ensure the worker call QStandardPaths::setTestModeEnabled too
 
         // wipe thumbnail cache so we always start clean
         QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
@@ -58,7 +65,7 @@ private Q_SLOTS:
         KFileItemList items;
         items.append(KFileItem(QUrl::fromLocalFile(path)));
 
-        QStringList enabledPlugins{"imagethumbnail", "jpegthumbnail"};
+        QStringList enabledPlugins{"svgthumbnail", "imagethumbnail", "jpegthumbnail"};
         auto *job = KIO::filePreview(items, QSize(128, 128), &enabledPlugins);
         job->setDevicePixelRatio(dpr);
 
@@ -69,6 +76,11 @@ private Q_SLOTS:
             expectedImage.load(QFINDTESTDATA("data/" + expectedThumbnail));
             expectedImage.setDevicePixelRatio(dpr);
 
+            if (expectedImage.format() == QImage::Format_ARGB32) {
+                // QImage load loads differently from KPreviewJob
+                expectedImage = expectedImage.convertToFormat(QImage::Format_ARGB32_Premultiplied);
+            }
+
             QCOMPARE(preview.devicePixelRatio(), dpr);
             QCOMPARE(preview.toImage(), expectedImage);
         });
@@ -77,10 +89,10 @@ private Q_SLOTS:
         QSignalSpy gotPreviewSpy(job, &KIO::PreviewJob::gotPreview);
         QSignalSpy resultSpy(job, &KIO::PreviewJob::result);
 
-        gotPreviewSpy.wait();
         resultSpy.wait();
 
-        QVERIFY(failedSpy.empty());
+        QVERIFY2(failedSpy.empty(), qPrintable(job->errorString()));
+        QVERIFY(!gotPreviewSpy.empty());
     }
 };
 
