@@ -21,19 +21,21 @@
 
 #include <QApplication>
 #include <QBuffer>
-#include <QFile>
-#include <QSaveFile>
-#include <QBitmap>
+#include <QColorSpace>
 #include <QCryptographicHash>
-#include <QImage>
-#include <QIcon>
-#include <QPixmap>
-#include <QUrl>
-#include <QMimeType>
-#include <QMimeDatabase>
-#include <QLibrary>
 #include <QDebug>
+#include <QDirIterator>
+#include <QFile>
+#include <QFileInfo>
+#include <QIcon>
+#include <QImage>
+#include <QLibrary>
+#include <QMimeDatabase>
+#include <QMimeType>
+#include <QPixmap>
 #include <QPluginLoader>
+#include <QSaveFile>
+#include <QUrl>
 
 #include <KConfigGroup>
 #include <KFileItem>
@@ -44,23 +46,8 @@
 #include <KPluginFactory>
 
 #include <kio_version.h>
-#if KIO_VERSION < QT_VERSION_CHECK(5, 240, 0)
-#include <KIO/ThumbCreator>
-#include <KIO/ThumbDevicePixelRatioDependentCreator>
-#include <KIO/ThumbSequenceCreator>
-#endif
-
-#include <QDirIterator>
 
 #include <limits>
-#include <variant>
-
-// Fix thumbnail: protocol
-#define THUMBNAIL_HACK (1)
-
-#ifdef THUMBNAIL_HACK
-# include <QFileInfo>
-#endif
 
 #include "imagefilter.h"
 
@@ -97,10 +84,10 @@ class KIOPluginForMetaData : public QObject
     Q_PLUGIN_METADATA(IID "org.kde.kio.worker.thumbnail" FILE "thumbnail.json")
 };
 
-extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
+extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 {
 #ifdef HAVE_NICE
-    nice( 5 );
+    nice(5);
 #endif
 
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
@@ -127,15 +114,15 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
     return 0;
 }
 
-
 ThumbnailProtocol::ThumbnailProtocol(const QByteArray &pool, const QByteArray &app)
-    : WorkerBase("thumbnail", pool, app),
-      m_width(0),
-      m_height(0),
-      m_devicePixelRatio(1),
-      m_maxFileSize(0),
-      m_randomGenerator()
-{}
+    : WorkerBase("thumbnail", pool, app)
+    , m_width(0)
+    , m_height(0)
+    , m_devicePixelRatio(1.0)
+    , m_maxFileSize(0)
+    , m_randomGenerator()
+{
+}
 
 ThumbnailProtocol::~ThumbnailProtocol()
 {
@@ -145,12 +132,25 @@ ThumbnailProtocol::~ThumbnailProtocol()
 /**
  * Scales down the image \p img in a way that it fits into the given maximum width and height
  */
-void scaleDownImage(QImage& img, int maxWidth, int maxHeight)
+void scaleDownImage(QImage &img, int maxWidth, int maxHeight)
 {
     if (img.width() > maxWidth || img.height() > maxHeight) {
-        img = img.scaled(maxWidth,
-                         maxHeight,
-                         Qt::KeepAspectRatio, Qt::SmoothTransformation);
+        img = img.scaled(maxWidth, maxHeight, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    }
+}
+
+/**
+ * @brief convertToStandardRgb
+ * Convert preview to sRGB for proper viewing on most monitors.
+ */
+void convertToStandardRgb(QImage &img)
+{
+    auto cs = img.colorSpace();
+    if (!cs.isValid()) {
+        return;
+    }
+    if (cs.transferFunction() != QColorSpace::TransferFunction::SRgb || cs.primaries() != QColorSpace::Primaries::SRgb) {
+        img.convertToColorSpace(QColorSpace(QColorSpace::SRgb));
     }
 }
 
@@ -159,7 +159,7 @@ KIO::WorkerResult ThumbnailProtocol::get(const QUrl &url)
     m_mimeType = metaData("mimeType");
     m_enabledPlugins = metaData("enabledPlugins").split(QLatin1Char(','), Qt::SkipEmptyParts);
     if (m_enabledPlugins.isEmpty()) {
-        const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
+        const KConfigGroup globalConfig(KSharedConfig::openConfig(), QStringLiteral("PreviewSettings"));
         m_enabledPlugins = globalConfig.readEntry("Plugins", KIO::PreviewJob::defaultPlugins());
     }
 
@@ -175,12 +175,10 @@ KIO::WorkerResult ThumbnailProtocol::get(const QUrl &url)
         return KIO::WorkerResult::fail(KIO::ERR_CANNOT_READ, url.path());
     }
 
-    //qDebug() << "Wanting MIME Type:" << m_mimeType;
-#ifdef THUMBNAIL_HACK
-    // ### HACK
-    bool direct=false;
+    // qDebug() << "Wanting MIME Type:" << m_mimeType;
+    bool direct = false;
     if (m_mimeType.isEmpty()) {
-        //qDebug() << "PATH: " << url.path() << "isDir:" << info.isDir();
+        // qDebug() << "PATH: " << url.path() << "isDir:" << info.isDir();
         if (info.isDir()) {
             m_mimeType = "inode/directory";
         } else {
@@ -189,10 +187,9 @@ KIO::WorkerResult ThumbnailProtocol::get(const QUrl &url)
             m_mimeType = db.mimeTypeForFile(info).name();
         }
 
-        //qDebug() << "Guessing MIME Type:" << m_mimeType;
-        direct=true; // thumbnail: URL was probably typed in Konqueror
+        // qDebug() << "Guessing MIME Type:" << m_mimeType;
+        direct = true; // thumbnail: URL was probably typed in Konqueror
     }
-#endif
 
     if (m_mimeType.isEmpty()) {
         return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("No MIME Type specified."));
@@ -203,18 +200,15 @@ KIO::WorkerResult ThumbnailProtocol::get(const QUrl &url)
 
     if (m_width < 0 || m_height < 0) {
         return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("No or invalid size specified."));
-    }
-#ifdef THUMBNAIL_HACK
-    else if (!m_width || !m_height) {
-        //qDebug() << "Guessing height, width, icon size!";
+    } else if (!m_width || !m_height) {
+        // qDebug() << "Guessing height, width, icon size!";
         m_width = 128;
         m_height = 128;
     }
-#endif
     bool ok;
-    m_devicePixelRatio = metaData("devicePixelRatio").toInt(&ok);
-    if (!ok || m_devicePixelRatio == 0) {
-        m_devicePixelRatio = 1;
+    m_devicePixelRatio = metaData("devicePixelRatio").toFloat(&ok);
+    if (!ok || qFuzzyIsNull(m_devicePixelRatio)) {
+        m_devicePixelRatio = 1.0;
     } else {
         m_width *= m_devicePixelRatio;
         m_height *= m_devicePixelRatio;
@@ -222,43 +216,29 @@ KIO::WorkerResult ThumbnailProtocol::get(const QUrl &url)
 
     QImage img;
     QString plugin = metaData("plugin");
-    if ((plugin.isEmpty() || plugin == "directorythumbnail") && m_mimeType == "inode/directory") {
+
+    if ((plugin.isEmpty() || plugin.contains("directorythumbnail")) && m_mimeType == "inode/directory") {
         img = thumbForDirectory(info.canonicalFilePath());
         if (img.isNull()) {
             return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("Cannot create thumbnail for directory"));
         }
     } else {
-#ifdef THUMBNAIL_HACK
         if (plugin.isEmpty()) {
             plugin = pluginForMimeType(m_mimeType).fileName();
         }
 
-        //qDebug() << "Guess plugin: " << plugin;
-#endif
+        // qDebug() << "Guess plugin: " << plugin;
         if (plugin.isEmpty()) {
             return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("No plugin specified."));
         }
 
-        ThumbCreatorWithMetadata* creator = getThumbCreator(plugin);
+        ThumbCreatorWithMetadata *creator = getThumbCreator(plugin);
         if (!creator) {
             return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("Cannot load ThumbCreator %1", plugin));
         }
 
         if (creator->handleSequences) {
-#if KIO_VERSION < QT_VERSION_CHECK(5, 240, 0)
-            if (std::holds_alternative<LegacyThumbCreatorPtr>(creator->creator)) {
-                auto *sequenceCreator = dynamic_cast<ThumbSequenceCreator *>(std::get<LegacyThumbCreatorPtr>(creator->creator).get());
-
-                if (sequenceCreator) {
-                    sequenceCreator->setSequenceIndex(sequenceIndex());
-                    setMetaData("handlesSequences", QStringLiteral("1"));
-                }
-            } else {
-                setMetaData("handlesSequences", QStringLiteral("1"));
-            }
-#else
             setMetaData("handlesSequences", QStringLiteral("1"));
-#endif
         }
 
         if (!createThumbnail(creator, info.canonicalFilePath(), m_width, m_height, img)) {
@@ -271,67 +251,73 @@ KIO::WorkerResult ThumbnailProtocol::get(const QUrl &url)
         }
     }
 
-    scaleDownImage(img, m_width, m_height);
-
     if (img.isNull()) {
         return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("Failed to create a thumbnail."));
     }
 
-    const QString shmid = metaData("shmid");
-    if (shmid.isEmpty()) {
-#ifdef THUMBNAIL_HACK
-        if (direct) {
-            // If thumbnail was called directly from Konqueror, then the image needs to be raw
-            //qDebug() << "RAW IMAGE TO STREAM";
-            QBuffer buf;
-            if (!buf.open(QIODevice::WriteOnly)) {
-                return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("Could not write image."));
-            }
-            img.save(&buf,"PNG");
-            buf.close();
-            mimeType("image/png");
-            data(buf.buffer());
+    // image quality and size corrections
+    scaleDownImage(img, m_width, m_height);
+
+    convertToStandardRgb(img);
+
+    if (img.colorCount() > 0) {
+        // images using indexed color format, are not loaded properly by QImage ctor using in shm code path
+        // convert the format to regular RGB
+        img = img.convertToFormat(img.hasAlphaChannel() ? QImage::Format_ARGB32 : QImage::Format_RGB32);
+    }
+
+    if (direct) {
+        // If thumbnail was called directly from Konqueror, then the image needs to be raw
+        // qDebug() << "RAW IMAGE TO STREAM";
+        QBuffer buf;
+        if (!buf.open(QIODevice::WriteOnly)) {
+            return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("Could not write image."));
         }
-        else
-#endif
-        {
-            QByteArray imgData;
-            QDataStream stream( &imgData, QIODevice::WriteOnly );
-            //qDebug() << "IMAGE TO STREAM";
-            stream << img;
-            mimeType("application/octet-stream");
-            data(imgData);
-        }
-    } else {
+        img.save(&buf, "PNG");
+        buf.close();
+        mimeType("image/png");
+        data(buf.buffer());
+        return KIO::WorkerResult::pass();
+    }
+
+    QByteArray imgData;
+    QDataStream stream(&imgData, QIODevice::WriteOnly);
+
+    // Keep in sync with kio/src/previewjob.cpp
+    stream << img.width() << img.height() << img.format() << img.devicePixelRatio();
+
 #ifndef Q_OS_WIN
-        QByteArray imgData;
-        QDataStream stream( &imgData, QIODevice::WriteOnly );
-        //qDebug() << "IMAGE TO SHMID";
+    const QString shmid = metaData("shmid");
+    if (shmid.isEmpty())
+#endif
+    {
+        // qDebug() << "IMAGE TO STREAM";
+        stream << img;
+    }
+#ifndef Q_OS_WIN
+    else {
+        // qDebug() << "IMAGE TO SHMID";
         void *shmaddr = shmat(shmid.toInt(), nullptr, 0);
         if (shmaddr == (void *)-1) {
             return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("Failed to attach to shared memory segment %1", shmid));
         }
-        if( img.format() != QImage::Format_ARGB32 ) { // KIO::PreviewJob and this code below completely ignores colortable :-/,
-            img = img.convertToFormat(QImage::Format_ARGB32); //  so make sure there is none
-        }
         struct shmid_ds shmStat;
         if (shmctl(shmid.toInt(), IPC_STAT, &shmStat) == -1 || shmStat.shm_segsz < (uint)img.sizeInBytes()) {
             return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, i18n("Image is too big for the shared memory segment"));
-            shmdt((char*)shmaddr);
+            shmdt((char *)shmaddr);
         }
-        // Keep in sync with kio/src/previewjob.cpp
-        const quint8 format = img.format() | 0x80;
-        stream << img.width() << img.height() << format << ((int)img.devicePixelRatio());
-        memcpy(shmaddr, img.bits(), img.sizeInBytes());
-        shmdt((char*)shmaddr);
-        mimeType("application/octet-stream");
-        data(imgData);
-#endif
+        memcpy(shmaddr, img.constBits(), img.sizeInBytes());
+        shmdt((char *)shmaddr);
     }
+#endif
+    mimeType("application/octet-stream");
+    data(imgData);
+
     return KIO::WorkerResult::pass();
 }
 
-KPluginMetaData ThumbnailProtocol::pluginForMimeType(const QString& mimeType) {
+KPluginMetaData ThumbnailProtocol::pluginForMimeType(const QString &mimeType)
+{
     const QVector<KPluginMetaData> plugins = KIO::PreviewJob::availableThumbnailerPlugins();
     for (const KPluginMetaData &plugin : plugins) {
         if (plugin.supportsMimeType(mimeType)) {
@@ -340,10 +326,10 @@ KPluginMetaData ThumbnailProtocol::pluginForMimeType(const QString& mimeType) {
     }
     for (const auto &plugin : plugins) {
         const QStringList mimeTypes = plugin.mimeTypes() + plugin.value(QStringLiteral("ServiceTypes"), QStringList());
-        for (const QString& mime : mimeTypes) {
-            if(mime.endsWith('*')) {
-                const auto mimeGroup = QStringView(mime).left(mime.length()-1);
-                if(mimeType.startsWith(mimeGroup)) {
+        for (const QString &mime : mimeTypes) {
+            if (mime.endsWith('*')) {
+                const auto mimeGroup = QStringView(mime).left(mime.length() - 1);
+                if (mimeType.startsWith(mimeGroup)) {
                     return plugin;
                 }
             }
@@ -353,21 +339,24 @@ KPluginMetaData ThumbnailProtocol::pluginForMimeType(const QString& mimeType) {
     return {};
 }
 
-float ThumbnailProtocol::sequenceIndex() const {
+float ThumbnailProtocol::sequenceIndex() const
+{
     return metaData("sequence-index").toFloat();
 }
 
 bool ThumbnailProtocol::isOpaque(const QImage &image) const
 {
     // Test the corner pixels
-    return qAlpha(image.pixel(QPoint(0, 0))) == 255 &&
-           qAlpha(image.pixel(QPoint(image.width()-1, 0))) == 255 &&
-           qAlpha(image.pixel(QPoint(0, image.height()-1))) == 255 &&
-           qAlpha(image.pixel(QPoint(image.width()-1, image.height()-1))) == 255;
+    return qAlpha(image.pixel(QPoint(0, 0))) == 255 && qAlpha(image.pixel(QPoint(image.width() - 1, 0))) == 255
+        && qAlpha(image.pixel(QPoint(0, image.height() - 1))) == 255 && qAlpha(image.pixel(QPoint(image.width() - 1, image.height() - 1))) == 255;
 }
 
-void ThumbnailProtocol::drawPictureFrame(QPainter *painter, const QPoint &centerPos,
-        const QImage &image, int borderStrokeWidth, QSize imageTargetSize, int rotationAngle) const
+void ThumbnailProtocol::drawPictureFrame(QPainter *painter,
+                                         const QPoint &centerPos,
+                                         const QImage &image,
+                                         int borderStrokeWidth,
+                                         QSize imageTargetSize,
+                                         int rotationAngle) const
 {
     // Scale the image down so it matches the aspect ratio
     float scaling = 1.0;
@@ -389,8 +378,9 @@ void ThumbnailProtocol::drawPictureFrame(QPainter *painter, const QPoint &center
     m.rotate(rotationAngle);
     m.scale(scaling, scaling);
 
-    const QRectF frameRect(QPointF(0, 0), QPointF(image.width() / image.devicePixelRatio() + scaledFrameWidth*2,
-                                                  image.height() / image.devicePixelRatio() + scaledFrameWidth*2));
+    const QRectF frameRect(
+        QPointF(0, 0),
+        QPointF(image.width() / image.devicePixelRatio() + scaledFrameWidth * 2, image.height() / image.devicePixelRatio() + scaledFrameWidth * 2));
 
     QRect r = m.mapRect(QRectF(frameRect)).toAlignedRect();
 
@@ -430,18 +420,18 @@ void ThumbnailProtocol::drawPictureFrame(QPainter *painter, const QPoint &center
     painter->drawImage(r.topLeft(), transformed);
 }
 
-QImage ThumbnailProtocol::thumbForDirectory(const QString& directory)
+QImage ThumbnailProtocol::thumbForDirectory(const QString &directory)
 {
     QImage img;
     if (m_propagationDirectories.isEmpty()) {
         // Directories that the directory preview will be propagated into if there is no direct sub-directories
-        const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
+        const KConfigGroup globalConfig(KSharedConfig::openConfig(), QStringLiteral("PreviewSettings"));
         const QStringList propagationDirectoriesList = globalConfig.readEntry("PropagationDirectories", QStringList() << "VIDEO_TS");
         m_propagationDirectories = QSet<QString>(propagationDirectoriesList.begin(), propagationDirectoriesList.end());
         m_maxFileSize = globalConfig.readEntry("MaximumSize", std::numeric_limits<qint64>::max());
     }
 
-    const int tiles = 2; //Count of items shown on each dimension
+    const int tiles = 2; // Count of items shown on each dimension
     const int spacing = 1 * m_devicePixelRatio;
     const int visibleCount = tiles * tiles;
 
@@ -460,7 +450,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const QString& directory)
         folder = folder.scaled(extent, extent, Qt::KeepAspectRatio, Qt::SmoothTransformation);
     }
 
-    const int folderWidth  = folder.width();
+    const int folderWidth = folder.width();
     const int folderHeight = folder.height();
 
     const int topMargin = folderHeight * 30 / 100;
@@ -471,8 +461,8 @@ QImage ThumbnailProtocol::thumbForDirectory(const QString& directory)
     // (i.e for each 170px the folder width increases those border increase by 1 px)
     const int borderStrokeWidth = qRound(folderWidth / 170.);
 
-    const int segmentWidth  = (folderWidth  - leftMargin - rightMargin  + spacing) / tiles - spacing;
-    const int segmentHeight = (folderHeight - topMargin  - bottomMargin + spacing) / tiles - spacing;
+    const int segmentWidth = (folderWidth - leftMargin - rightMargin + spacing) / tiles - spacing;
+    const int segmentHeight = (folderHeight - topMargin - bottomMargin + spacing) / tiles - spacing;
     if ((segmentWidth < 5 * m_devicePixelRatio) || (segmentHeight < 5 * m_devicePixelRatio)) {
         // the segment size is too small for a useful preview
         return img;
@@ -565,7 +555,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const QString& directory)
         if (!dir.hasNext() && totalValidThumbs < 0) {
             // We iterated over the entire directory for the first time, so now we know how many thumbs
             // were actually created.
-            totalValidThumbs = skipped+validThumbnails;
+            totalValidThumbs = skipped + validThumbnails;
         }
 
         if (validThumbnails > 0) {
@@ -588,7 +578,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const QString& directory)
     if (totalValidThumbs >= 0) {
         // We only know this once we've iterated over the entire directory, so this will only be
         // set for large enough sequence indices.
-        const int wraparoundPoint = (totalValidThumbs-1)/visibleCount + 1;
+        const int wraparoundPoint = (totalValidThumbs - 1) / visibleCount + 1;
         setMetaData("sequenceIndexWraparoundPoint", QString().setNum(wraparoundPoint));
     }
     setMetaData("handlesSequences", QStringLiteral("1"));
@@ -634,7 +624,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const QString& directory)
     return img;
 }
 
-ThumbCreatorWithMetadata* ThumbnailProtocol::getThumbCreator(const QString& plugin)
+ThumbCreatorWithMetadata *ThumbnailProtocol::getThumbCreator(const QString &plugin)
 {
     auto it = m_creators.constFind(plugin);
     if (it != m_creators.constEnd()) {
@@ -656,51 +646,6 @@ ThumbCreatorWithMetadata* ThumbnailProtocol::getThumbCreator(const QString& plug
         return creator;
     }
 
-#if KIO_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    // Don't use KPluginFactory here, this is not a QObject and
-    // neither is ThumbCreator
-    ThumbCreator *creator = nullptr;
-    QLibrary library(QPluginLoader(plugin).fileName());
-    if (library.load()) {
-        auto createFn = (newCreator)library.resolve("new_creator");
-        if (createFn) {
-            creator = createFn();
-        }
-    }
-
-    ThumbCreatorWithMetadata *thumbCreator = nullptr;
-    if (creator) {
-        KPluginMetaData data;
-        if (plugin.contains(QLatin1String("kf5/thumbcreator"))) {
-            data = KPluginMetaData(plugin);
-        } else {
-            const QVector<KPluginMetaData> plugins = KIO::PreviewJob::availableThumbnailerPlugins();
-            auto findPluginIt = std::find_if(plugins.begin(), plugins.end(), [&plugin](const KPluginMetaData &data) {
-                return data.fileName() == plugin;
-            });
-            if (findPluginIt != plugins.end()) {
-                data = *findPluginIt;
-            }
-        }
-        if (!data.isValid()) {
-            qCWarning(KIO_THUMBNAIL_LOG) << "Plugin not found:" << plugin;
-        } else {
-            thumbCreator = new ThumbCreatorWithMetadata{
-                std::unique_ptr<ThumbCreator>(creator),
-                data.value("CacheThumbnail", true),
-                data.value("DevicePixelRatioDependent", false),
-                data.value("HandleSequences", false),
-            };
-        }
-    } else {
-        qCWarning(KIO_THUMBNAIL_LOG) << "Failed to load" << plugin << library.errorString();
-    }
-
-    m_creators.insert(plugin, thumbCreator);
-
-    return thumbCreator;
-#endif
-
     return nullptr;
 }
 
@@ -722,19 +667,18 @@ void ThumbnailProtocol::ensureDirsCreated()
     }
 }
 
-bool ThumbnailProtocol::createSubThumbnail(QImage &thumbnail, const QString &filePath,
-                                           int segmentWidth, int segmentHeight)
+bool ThumbnailProtocol::createSubThumbnail(QImage &thumbnail, const QString &filePath, int segmentWidth, int segmentHeight)
 {
-    auto getSubCreator = [&filePath, this]() -> ThumbCreatorWithMetadata* {
+    auto getSubCreator = [&filePath, this]() -> ThumbCreatorWithMetadata * {
         const QMimeDatabase db;
-        const KPluginMetaData  subPlugin = pluginForMimeType(db.mimeTypeForFile(filePath).name());
+        const KPluginMetaData subPlugin = pluginForMimeType(db.mimeTypeForFile(filePath).name());
         if (!subPlugin.isValid() || !m_enabledPlugins.contains(subPlugin.pluginId())) {
             return nullptr;
         }
         return getThumbCreator(subPlugin.fileName());
     };
 
-    const auto maxDimension = qMin(1024, 512 * m_devicePixelRatio);
+    const auto maxDimension = qMin(1024.0, 512.0 * m_devicePixelRatio);
     if ((segmentWidth <= maxDimension) && (segmentHeight <= maxDimension)) {
         // check whether a cached version of the file is available for
         // 128 x 128, 256 x 256 pixels or 512 x 512 pixels taking into account devicePixelRatio
@@ -775,7 +719,7 @@ bool ThumbnailProtocol::createSubThumbnail(QImage &thumbnail, const QString &fil
 
         // no cached version is available, a new thumbnail must be created
         if (thumbnail.isNull()) {
-            ThumbCreatorWithMetadata* subCreator = getSubCreator();
+            ThumbCreatorWithMetadata *subCreator = getSubCreator();
             if (subCreator && createThumbnail(subCreator, filePath, cacheSize, cacheSize, thumbnail)) {
                 scaleDownImage(thumbnail, cacheSize, cacheSize);
 
@@ -817,7 +761,7 @@ bool ThumbnailProtocol::createSubThumbnail(QImage &thumbnail, const QString &fil
     } else {
         // image requested is too big to be stored in the cache
         // create an image on demand
-        ThumbCreatorWithMetadata* subCreator = getSubCreator();
+        ThumbCreatorWithMetadata *subCreator = getSubCreator();
         if (!subCreator || !createThumbnail(subCreator, filePath, segmentWidth, segmentHeight, thumbnail)) {
             return false;
         }
@@ -829,48 +773,16 @@ bool ThumbnailProtocol::createSubThumbnail(QImage &thumbnail, const QString &fil
     return true;
 }
 
-bool ThumbnailProtocol::createThumbnail(ThumbCreatorWithMetadata* thumbCreator, const QString& filePath, int width, int height, QImage& thumbnail)
+bool ThumbnailProtocol::createThumbnail(ThumbCreatorWithMetadata *thumbCreator, const QString &filePath, int width, int height, QImage &thumbnail)
 {
     bool success = false;
 
-#if KIO_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    if (std::holds_alternative<LegacyThumbCreatorPtr>(thumbCreator->creator)) {
-        auto creator = std::get<LegacyThumbCreatorPtr>(thumbCreator->creator).get();
+    auto result = thumbCreator->creator->create(
+        KIO::ThumbnailRequest(QUrl::fromLocalFile(filePath), QSize(width, height), m_mimeType, m_devicePixelRatio, sequenceIndex()));
 
-        int scaledWidth = width;
-        int scaledHeight = height;
-
-        if (thumbCreator->devicePixelRatioDependent) {
-            auto *dprDependentCreator = static_cast<KIO::ThumbDevicePixelRatioDependentCreator *>(creator);
-
-            if (dprDependentCreator) {
-                dprDependentCreator->setDevicePixelRatio(m_devicePixelRatio);
-            }
-
-            scaledWidth /= m_devicePixelRatio;
-            scaledHeight /= m_devicePixelRatio;
-        }
-
-        success = creator->create(filePath, scaledWidth, scaledHeight, thumbnail);
-
-        if (thumbCreator->handleSequences) {
-            auto *sequenceCreator = dynamic_cast<ThumbSequenceCreator *>(creator);
-            m_sequenceIndexWrapAroundPoint = sequenceCreator->sequenceIndexWraparoundPoint();
-        }
-
-    }
-    else {
-#endif
-        auto result = std::get<ThumbnailCreatorPtr>(thumbCreator->creator)
-                          ->create(KIO::ThumbnailRequest(QUrl::fromLocalFile(filePath), QSize(width, height), m_mimeType, m_devicePixelRatio, sequenceIndex()));
-
-        success = result.isValid();
-        thumbnail = result.image();
-        m_sequenceIndexWrapAroundPoint = result.sequenceIndexWraparoundPoint();
-
-#if KIO_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    }
-#endif
+    success = result.isValid();
+    thumbnail = result.image();
+    m_sequenceIndexWrapAroundPoint = result.sequenceIndexWraparoundPoint();
 
     if (!success) {
         return false;
@@ -880,16 +792,17 @@ bool ThumbnailProtocol::createThumbnail(ThumbCreatorWithMetadata* thumbCreator,
     scaleDownImage(thumbnail, width, height);
 
     thumbnail.setDevicePixelRatio(m_devicePixelRatio);
+    convertToStandardRgb(thumbnail);
 
     return true;
 }
 
-void ThumbnailProtocol::drawSubThumbnail(QPainter& p, QImage subThumbnail, int width, int height, int xPos, int yPos, int borderStrokeWidth)
+void ThumbnailProtocol::drawSubThumbnail(QPainter &p, QImage subThumbnail, int width, int height, int xPos, int yPos, int borderStrokeWidth)
 {
     scaleDownImage(subThumbnail, width, height);
 
     // center the image inside the segment boundaries
-    const QPoint centerPos((xPos + width/ 2) / m_devicePixelRatio, (yPos + height / 2) / m_devicePixelRatio);
+    const QPoint centerPos((xPos + width / 2) / m_devicePixelRatio, (yPos + height / 2) / m_devicePixelRatio);
     const int rotationAngle = m_randomGenerator.bounded(-8, 9); // Random rotation ±8°
     drawPictureFrame(&p, centerPos, subThumbnail, borderStrokeWidth, QSize(width, height), rotationAngle);
 }
