@@ -9,29 +9,20 @@
 
 #include <QHash>
 #include <QPainter>
-#include <QSet>
 #include <QRandomGenerator>
+#include <QSet>
 
+#include <KIO/ThumbnailCreator>
 #include <KIO/WorkerBase>
 #include <KPluginMetaData>
-#include <KIO/ThumbnailCreator>
 
 #include <kio_version.h>
 
 class ThumbCreator;
 class QImage;
 
-#if KIO_VERSION < QT_VERSION_CHECK(5, 240, 0)
-using LegacyThumbCreatorPtr = std::unique_ptr<ThumbCreator>;
-using ThumbnailCreatorPtr = std::unique_ptr<KIO::ThumbnailCreator>;
-using Creator = std::variant<LegacyThumbCreatorPtr, ThumbnailCreatorPtr>;
-#else
-using ThumbnailCreatorPtr = std::unique_ptr<KIO::ThumbnailCreator>;
-using Creator = std::variant<ThumbnailCreatorPtr>;
-#endif
-
 struct ThumbCreatorWithMetadata {
-    Creator creator;
+    std::unique_ptr<KIO::ThumbnailCreator> creator;
     bool cacheThumbnail = true;
     bool devicePixelRatioDependent = false;
     bool handleSequences = false;
@@ -46,12 +37,11 @@ public:
     KIO::WorkerResult get(const QUrl &url) override;
 
 protected:
-    ThumbCreatorWithMetadata* getThumbCreator(const QString& plugin);
+    ThumbCreatorWithMetadata *getThumbCreator(const QString &plugin);
     bool isOpaque(const QImage &image) const;
-    void drawPictureFrame(QPainter *painter, const QPoint &pos, const QImage &image,
-                          int frameWidth, QSize imageTargetSize, int rotationAngle) const;
-    QImage thumbForDirectory(const QString& directory);
-    KPluginMetaData pluginForMimeType(const QString& mimeType);
+    void drawPictureFrame(QPainter *painter, const QPoint &pos, const QImage &image, int frameWidth, QSize imageTargetSize, int rotationAngle) const;
+    QImage thumbForDirectory(const QString &directory);
+    KPluginMetaData pluginForMimeType(const QString &mimeType);
 
     float sequenceIndex() const;
 
@@ -62,24 +52,23 @@ private:
      * If no cached version is available, the created sub thumbnail will be
      * added to the cache for later use.
      */
-    bool createSubThumbnail(QImage& thumbnail, const QString& filePath,
-                            int segmentWidth, int segmentHeight);
+    bool createSubThumbnail(QImage &thumbnail, const QString &filePath, int segmentWidth, int segmentHeight);
 
     /**
      * Draw the SubThumbnail
      **/
-    void drawSubThumbnail(QPainter& p, QImage subThumbnail, int width, int height,
-                          int xPos, int yPos, int borderStrokeWidth);
+    void drawSubThumbnail(QPainter &p, QImage subThumbnail, int width, int height, int xPos, int yPos, int borderStrokeWidth);
+
 private:
     void ensureDirsCreated();
-    bool createThumbnail(ThumbCreatorWithMetadata* subCreator, const QString& filePath, int width, int height, QImage& thumbnail);
+    bool createThumbnail(ThumbCreatorWithMetadata *subCreator, const QString &filePath, int width, int height, QImage &thumbnail);
 
     QString m_mimeType;
     int m_width;
     int m_height;
-    int m_devicePixelRatio;
+    qreal m_devicePixelRatio;
     // Thumbnail creators
-    QHash<QString, ThumbCreatorWithMetadata*> m_creators;
+    QHash<QString, ThumbCreatorWithMetadata *> m_creators;
     QStringList m_enabledPlugins;
     QSet<QString> m_propagationDirectories;
     QString m_thumbBasePath;
